
### Installation

_Below is an example of how you can instruct your audience on installing and setting up your app. This template doesn't rely on any external dependencies or services._

1. Clone the repo
    ```shell
    git clone https://github.com/URV-teacher/bmde
    ```
2. Enter the directory
    ```shell
    cd bmde
    ```
3. Install package
    ```shell
    make install
    ```
4. Call the CLI help to check that it has been installed properly
    ```shell
    ./venv/bin/bmde --help
    ```

Install pre-commit hooks:
```shell
./venv/bin/pre-commit install
```
